"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLintStatus = getLintStatus;
exports.getSummaryOfLint = getSummaryOfLint;
exports.writeSummaryOfLint = writeSummaryOfLint;
var _path = _interopRequireDefault(require("path"));
var _fileUtils = require("../../utils/fileUtils");
var _getFileUtils = require("../eslint/getFileUtils");
var _getSonarProperties = require("./getSonarProperties");
/**
 * @function getSummaryOfLint -  get summary of lint process 
 * @param {Object} cliParams - Object represent cli Argument 
 * @returns {Object}
 */

function getSummaryOfLint(cliParams) {
  const {
    lintJsonPath = null
  } = cliParams;
  var $projectName = (0, _getSonarProperties.getProjectName)(cliParams);
  return {
    projectName: $projectName,
    reportUrl: `https://serverlinter-np.zohodesk.csez.zohocorpin.com/project/issues?id=${$projectName}&resolved=false`,
    jsonReportPath: lintJsonPath || (0, _getFileUtils.getLintReportPath)().toString()
  };
}

/**
 * @function getLintStatus - get status of lint based on report
 * @param {Boolean} impactBased - argument from cli to decide to lint based on impact or not
 * @returns {Object}
 */

function getLintStatus(impactBased) {
  if (global.reportStatus || !impactBased) {
    return {
      status: reportStatus
    };
  }
  return {
    status: reportStatus
  };
}

/**
 * @function writeSummaryOfLint - write a summary of lint report ans it's status
 * @param {Object} cliParams -  Object represent cli Argument 
 * @returns {void}
 */

function writeSummaryOfLint(cliParams) {
  const {
    impactBased
  } = cliParams;
  (0, _fileUtils.writeFileContents)(_path.default.resolve(process.cwd(), "lint-report", "lint-summary.json"), JSON.stringify({
    ...getSummaryOfLint(cliParams),
    ...getLintStatus(impactBased)
  }));
}