const path = require("path");

/**
 * Configuration object for linting and reporting.
 * @typedef {Object} LintConfiguration
 * @property {string} ruleConfigurationPath - The path to the ESLint configuration file.
 * @property {boolean} impactBased - Indicates if the linting is impact-based.
 * @property {string} lintDirectory - The directory path where the linting will occur.
 * @property {string} lintReportPath - The path to the lint report JSON file.
 * @property {string} sonar_host_URL - The URL of the SonarQube server.
 * @property {string} loginName - The username for authentication with the SonarQube server.
 * @property {string} password - The password for authentication with the SonarQube server.
 */

/**
 * Linting configuration settings.
 * @type {LintConfiguration}
 */

module.exports = {
  ruleConfigurationPath: path.resolve(process.cwd(), ".eslintrc.js"),
  impactBased: false,
  lintDirectory: path.resolve(process.cwd()),
  lintReportPath: path.resolve(process.cwd(), "lint-report", "lintReport.json"),
  sonar_host_URL: "https://serverlinter-np.zohodesk.csez.zohocorpin.com/",
  loginName: "developer",
  password: "developer",
};
